// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef GEOMETRY_MSGS__MSG__POINT32_HPP_
#define GEOMETRY_MSGS__MSG__POINT32_HPP_

#include "geometry_msgs/msg/detail/point32__struct.hpp"
#include "geometry_msgs/msg/detail/point32__builder.hpp"
#include "geometry_msgs/msg/detail/point32__traits.hpp"
#include "geometry_msgs/msg/detail/point32__type_support.hpp"

#endif  // GEOMETRY_MSGS__MSG__POINT32_HPP_
