// generated from rosidl_adapter/resource/msg.idl.em
// with input from geometry_msgs/msg/PolygonInstance.msg
// generated code does not contain a copyright notice

#include "geometry_msgs/msg/Polygon.idl"

module geometry_msgs {
  module msg {
    @verbatim (language="comment", text=
      "A specification of a polygon where the first and last points are assumed to be connected" "\n"
      "It includes a unique identification field for disambiguating multiple instances")
    struct PolygonInstance {
      geometry_msgs::msg::Polygon polygon;

      int64 id;
    };
  };
};
