// generated from rosidl_generator_c/resource/idl.h.em
// with input from geometry_msgs:msg/Inertia.idl
// generated code does not contain a copyright notice

#ifndef GEOMETRY_MSGS__MSG__INERTIA_H_
#define GEOMETRY_MSGS__MSG__INERTIA_H_

#include "geometry_msgs/msg/detail/inertia__struct.h"
#include "geometry_msgs/msg/detail/inertia__functions.h"
#include "geometry_msgs/msg/detail/inertia__type_support.h"

#endif  // GEOMETRY_MSGS__MSG__INERTIA_H_
