// generated from rosidl_adapter/resource/msg.idl.em
// with input from geometry_msgs/msg/Point.msg
// generated code does not contain a copyright notice


module geometry_msgs {
  module msg {
    @verbatim (language="comment", text=
      "This contains the position of a point in free space")
    struct Point {
      double x;

      double y;

      double z;
    };
  };
};
